Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon DataZone Control.

Actions, resources, and condition keys for Amazon DataZone Control - Service Authorization Reference

# Actions, resources, and condition keys for Amazon DataZone Control

Amazon DataZone Control (service prefix: `datazonecontrol` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon DataZone Control
- Resource types defined by Amazon DataZone Control
- Condition keys for Amazon DataZone Control

## Actions defined by Amazon DataZone Control

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAccountAssociationInvitation [permission only] | Grants permission to request association of an account with a given domain | Write |  |  |
CreateDataSource [permission only] | Grants permission to create Amazon DataZone data sources used for publishing and subscribing to data | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateEnvironment [permission only] | Grants permission to provision a root-domain which is a top level entity that contains other Amazon DataZone resources | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteDataSource [permission only] | Grants permission to delete a data source | Write | data-source* |  |
DeleteEnvironment [permission only] | Grants permission to delete a provisioned root-domain | Write | environment* |  |
DissociateAccount [permission only] | Grants permission to disassociate an account with a given domain | Write |  |  |
GetAssociatedDomain [permission only] | Grants permission to retrieve information about any associated domain in the associated account | Read |  |  |
GetDataSourceByEnvironment [permission only] | Grants permission to retrieve any data source under any domain for a given root-domain | Read | data-source* |  |
GetDomain [permission only] | Grants permission to retrieve information about any domain in the account | Read |  |  |
GetEnvironment [permission only] | Grants permission to retrieve information about a root-domain | Read | environment* |  |
GetMetadataCollector [permission only] | Grants permission to retrieve a publishing job | Read |  |  |
GetUserPortalLoginAuthCode [permission only] | Grants permission to retrieve credentials to log into Amazon DataZone data portal from AWS management console | Read |  |  |
ListAccountAssociationInvitations [permission only] | Grants permission to retrieve all account-association invitations for a given associated account | List |  |  |
ListAllAssociatedAccountsForEnvironment [permission only] | Grants permission to list all associated accounts under the given root-domain, including accounts associated to its sub-domains | List |  |  |
ListAssociatedEnvironments [permission only] | Grants permission to lists all the associated domains for a given associated account | List |  |  |
ListDataSources [permission only] | Grants permission to retrieve all data sources under any domain in the associated account | List |  |  |
ListDataSourcesByEnvironment [permission only] | Grants permission to retrieve all data sources under any domain for a given root-domain | List |  |  |
ListDomains [permission only] | Grants permission to list all the sub-domains for a given domain or a root-domain | List |  |  |
ListEnvironment [permission only] | Grants permission to retrieve all root-domains | List |  |  |
ListMetadataCollectorRuns [permission only] | Grants permission to list all runs for a given publishing job through Amazon DataZone console for a data source | List |  |  |
ListMetadataCollectors [permission only] | Grants permission to retrieve all publishing jobs | List |  |  |
ListProjects [permission only] | Grants permission to retrieve all Amazon DataZone projects | List |  |  |
ListTagsForResource [permission only] | Grants permission to retrieve all tags associated with a resource | Read | data-source |  |
environment |  |
ReviewAccountAssociationInvitation [permission only] | Grants permission to accept or reject the pending association requests for the given account | Write |  |  |
TagResource [permission only] | Grants permission to add or update tags to a resource | Tagging | data-source |  |
environment |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource [permission only] | Grants permission to remove tags associated with a resource | Tagging | data-source |  |
environment |  |
| aws:TagKeys |
UpdateAccountAssociationDescription [permission only] | Grants permission to update the description of the account association of the given associated account and given domain | Write |  |  |
UpdateDataSource [permission only] | Grants permission to update a data source | Write | data-source* |  |
UpdateEnvironment [permission only] | Grants permission to update information for a root-domain | Write | environment* |  |

## Resource types defined by Amazon DataZone Control

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
environment | `arn:$ { Partition}:datazonecontrol:$ { Region}:$ { Account}:domain/$ { DomainId}` | aws:ResourceTag/${TagKey}
data-source | `arn:$ { Partition}:datazonecontrol:$ { Region}:$ { Account}:data-source/$ { DomainId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon DataZone Control

Amazon DataZone Control defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.